#  Bailey and MacKinnon-Webb empirical example
#  from
#  Standard Errors for Difference-in-Difference Regression
#  Bruce E Hansen
#  October 2024
#
#  creates results for Tables 12 & 13
#
#  This is a R file
#  Identical results are generated by Stata file Bailey.do
#
#  The file loads the data file Bailey.dta
#  It requires the R file jregress.R (place in same folder)
#  Uses the R packages haven and estimatr


library(haven)
library(estimatr)
source("jregress.R")
dat <- read_dta("Bailey.dta")

c <- dat$cstck
c[is.na(c)] <- 0

dat$year_1965 <- 1*(dat$year==1965)
dat$year_1970 <- 1*(dat$year==1970)
dat$repeal61 <- (c==1961)
dat$sales_1970 <- dat$sales*dat$year_1970
dat$i.year <- as.factor(dat$year)
dat$Phys_1970 <- dat$Phys*dat$year_1970
dat$i.region <- as.factor(dat$region)

#   Table 12

lm_robust(pill~sales+sales_1970+Phys+Phys_1970+i.region*i.year, data=dat, clusters=statefip,se_type="stata")

jack1 <- jregress(pill~sales+sales_1970+Phys+Phys_1970+i.region*i.year, data=dat, clusters=statefip, df.display = TRUE)

#   Table 13

lm_robust(pill~sales+sales_1970+repeal61+Phys+Phys_1970+i.region*i.year, data=dat, clusters=statefip,se_type="stata")

jack1 <- jregress(pill~sales+sales_1970+repeal61+Phys+Phys_1970+i.region*i.year, data=dat, clusters=statefip, df.display = TRUE)

