***************************************************
* Author: Brue Hansen, modification of master_NFS_AER.do of Martha Bailey
* Date: 3/7/2024
* To run, download replication package for "Momma's Got the Pill" by Martha Bailey, American Economic Review, 2010
* https://www.openicpsr.org/openicpsr/project/112340/version/V1/view
* Extract the following files: appenddata.do, createvars.do, gaf55_1.dta, griswoldlaws5.dta, nfs65_1.dta, nfs70_1.dta, statefipsname.dta
* Edit path names below
* Run this file. It will create the stata file "Bailey.dta"
***************************************************

version 10.1
clear

* Edit this path name to match file location
local dir "D:\Dropbox\work\did\empirical\Bailey"

global data65 `dir' 		/*Where nfs65_1.dta is stored*/
global data55 `dir' 		/*Where gaf55_1.dta is stored*/
global data70 `dir' 		/*Where nfs70_1.dta is stored*/
global datatemp `dir' 		/*Optional: Location where temporary files will be saved*/
global dofile  `dir' 		/*Where dofiles are saved*/
global output  `dir'		/*Where dofiles will store output such as logfiles*/

do createvars		/*Create contraception variables in 1955 GAF, 1960 & 1970 NFS*/
do appenddata		/*Append and harmonize variables in 1955 GAF, 1960 & 1970 NFS*/

keep if _Married==1 & _White==1 & _age<40 & _age>=18
keep if year!= 1955
drop _White _Married att_famplan _everuse wgt _approvefp55 _I_region_2 _I_region_3 _I_region_4 
drop _I_hinccat_1 _I_hinccat_2 _I_hinccat_3  _I_hinccat_4 _I_idealcat_2 _I_idealcat_3 _I_idealcat_4 _I_idealcat_5
drop _I_ed_cat_9 _I_ed_cat_12 _I_ed_cat_13 _I_ed_cat_16 __yobcat

rename _oral pill
rename _fecund fecund
rename _everuse_d everuse_d
rename _barrier barrier
rename _supplies supplies
rename _region region
rename _everuse2_mjb everuse2_mjb
rename _everuse3_mjb everuse3_mjb
rename _ed_cat ed_cat
rename _Catholic Catholic
rename _yob yob
rename _yobcat yobcat
rename _age age
rename _agecat agecat
rename _sterilop sterilop
rename _att_idealch att_idealch
rename _idealcat idealcat
rename _hinccat hinccat
rename _coit_freq coit_freq
rename _Phys Phys
rename _Phy_LB Phy_LB

save "Bailey", replace
export delimited using Bailey.csv, delimiter(tab) replace

erase temp.dta
erase temp55.dta
erase temp65.dta
erase temp70.dta
erase temp556570.dta
