#  Rao empirical example
#  from
#  Standard Errors for Difference-in-Difference Regression
#  Bruce E Hansen
#  October 2024
#
#  creates results for Tables 14 & 15
#
#  This is a R file
#  Identical results are generated by Stata file Rao.do
#
#  The file loads the data files dataMain.dta and dataDiscriminationExperiment.dta
#  It requires the R file jregress.R (place in same folder)
#  Uses the R packages haven and estimatr

library(haven)
library(estimatr)
source("jregress.R")

#   Table 14

dataMain <- read_dta("dataMain.dta")
dataMain$i.grade <- as.factor(dataMain$grade)
dataMain$i.school_id <- as.factor(dataMain$school_id)

lm_robust(charity_task~treatedClassroom+age+male+ownsCar+transCar+i.grade+i.school_id, data=dataMain, clusters=school_grade, se_type="stata")

jack <- jregress(charity_task~treatedClassroom+age+male+ownsCar+transCar+i.grade+i.school_id, data=dataMain, clusters=school_grade, df.display = TRUE)


#   Table 15

dataDiscriminationExperiment <- read_dta("dataDiscriminationExperiment.dta")
dataDiscriminationExperiment$i.grade <- as.factor(dataDiscriminationExperiment$grade)
dataDiscriminationExperiment$i.school <- as.factor(dataDiscriminationExperiment$school)

lm_robust(Discriminated~treatedClassroom+Prize200+Prize500+treatedClassroom_X_Prize200+treatedClassroom_X_Prize500+i.grade+i.school, data=dataDiscriminationExperiment, clusters=school_grade, se_type="stata")

jack <- jregress(Discriminated~treatedClassroom+Prize200+Prize500+treatedClassroom_X_Prize200+treatedClassroom_X_Prize500+i.grade+i.school, data=dataDiscriminationExperiment, clusters=school_grade, df.display = TRUE)


