/* example.do

Illustrates use of jackknife code 'jregress.ado'.
Implements methods from "Jackknife standard errors for clustered regression"
by Bruce E. Hansen

This example file uses the pre-processed data file Meng_1.dta.
The file jregress.ado needs to be in the same folder.

Five example regressions are shown. All report jackknife standard errors.

The first example calculates the regression for the model corresponding to the first column of Table 7 of the Meng, Qian, and Yared (2015), but with jackknife standard errors clustered by province, and inference (p-values and condfidence intervals) calculated by the adjusted t distribution.

The second example repeats this regression but omits clustering.

The third example repeats the first regression and displays the adjustment coefficients.

The fourth example repeats the first regression but calculates inference by the standard t distribution.

The fifth example takes the first regression and adds cluster-level fixed effects.

The sixth example adds two cluster-level dummy variable indicators to the first regression. The dummy variables fail clusterwise invertibility. The regression and standard errors are reported, but a warning message is displayed.
*/

clear all
use Meng_1, clear

drop if lgrain_pred_famdum5860==.
keep if year >= 1953
keep if year <= 1982

gen diff_pred = lgrain_pred_famdum5860 - lgrain_pred
gen Beijing = (province == "Beijing")
gen Tianjin = (province == "Tianjin")

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop i.year, cluster(prov)

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop i.year

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop i.year, cluster(prov) dfdisplay

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop i.year, cluster(prov) noadjust

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop i.year, cluster(prov) fe 

jregress ldeath_b diff_pred lgrain_pred ltotpop lurbpop Beijing Tianjin i.year, cluster(prov)
