#-----------------------------------------------------#
# Table16.R
#
# This program uses the R package estimatr, and uses the program file jregress.R
#
# This calculates the R portion of Table 16
#-----------------------------------------------------#
Ns <- c(100,1000)		# number of observations per clusteer
Gs <- c(20,200)			# number of clusters
ks <- c(10,50,100,200)		# number of regressors
seed <- 10232023		# random number seed 
Table = "Table16.txt"		# File for printed output
#-----------------------------------------------------#

source('jregress.R')
library(estimatr)

set.seed(seed) 
Gn <- length(Gs)
kn <- length(ks)
Nn <- length(Ns)

timestore <- matrix(0,Gn*kn*Nn,5)

for (gi in 1:Gn){
G <- Gs[gi]
groups <- seq(G)

for (ni in 1:Nn) {
N <- Ns[ni]

ng <- rep(N,G)
group  <- rep(groups,ng)
n <- length(group)

for (ki in 1:kn) {
k <- ks[ki]

if (k < n) {

Y <- matrix(rnorm(n),n,1)
dat <- data.frame(Y,group)

for (i in 1:k) {
  Xi <- data.frame(rnorm(n))
  colnames(Xi) <- c(paste("X", i, sep=""))
  dat <- cbind(dat, Xi)
}
form <- reformulate(grep("^X", names(dat), value = TRUE), response = "Y")
t0 <- Sys.time()

est1 <- lm_robust(form, data=dat, clusters=group,se_type="stata")
t1 <- Sys.time() 

est2 <- jregress(form, data=dat, clusters=group,df.display = FALSE,print = FALSE)
t2 <- Sys.time() 


ti <- (gi-1)*Nn*kn + (ni-1)*kn + ki
timestore[ti,1] <- G
timestore[ti,2] <- N
timestore[ti,3] <- k
timestore[ti,4] <- t1-t0
timestore[ti,5] <- t2-t1

}

}	# end ki
}	# end ni
}	# end gi

logt <- log(timestore)
timeG <- logt[,1]
timeng <- logt[,2]
timek <- logt[,3]
time1 <- logt[,4]
timej <- logt[,5]
datt <- data.frame(timeG,timeng,timek,time1,timej)

sink(Table)
cat("Time in seconds\n")
cat("First column is number of clusters\n")
cat("Second column is number of observations per cluster\n")
cat("Third column is number of regressors\n")
cat("Fourth column is CRVE1 (lm_robust)\n")
cat("Fifth column is jackknife (jregress)\n")
print.table(round(timestore,3))

cat("Computation Time Regression\n")
estt <- jregress(timej~timeG+timeng+timek, data=datt, df.display = FALSE,print = TRUE)

sink()


